C ESA (C) 2000-2018 
C
C This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
C
C    SAS is free software: you can redistribute it and/or modify
C    it under the terms of the GNU General Public License as published by
C    the Free Software Foundation, either version 3 of the License, or
C    (at your option) any later version.
C
C    SAS is distributed in the hope that it will be useful,
C    but WITHOUT ANY WARRANTY; without even the implied warranty of
C    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C    GNU General Public License for more details.
C
C    You should have received a copy of the GNU General Public License
C    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
C-----------------------------------------------------------------------
C
      SUBROUTINE GJ2EFS(TMJD,XJ2000,XEFS)
C
C-----------------------------------------------------------------------
C
C  AUTHOR: FABIENNE DELHAISE  EDS/FDD/ESOC
C  ******
C
C  PURPOSE:
C  *******
C  CONVERTS S/V FROM THE GEOCENTRIC MEAN OF DATE J-2000 REFERENCE SYSTEM
C  TO THE PSEUDO-EARTH FIXED REFERENCE SYSTEM.
C  *** SIMPLIFIED VERSION ***
C  FOLLOWING SIMPLIFICATIONS:  NO NUTATION,
C                              NO POLAR MOTION
C                              NO UTC - UT1 CORRECTION
C
C  INPUT:
C  *****
C  TMJD:         R*8: EPOCH IN MODIFIED JULIAN DATE FROM 2000
C  XJ2000(1..3) 3R*8: S/C POSITION IN THE J-2000 SYSTEM (KM)
C
C  OUTPUT:
C  *******
C  XEFS(1..3)   3R*8: S/C POSITION IN THE PSEUDO-EARTH FIXED SYSTEM
C-----------------------------------------------------------------------
C
C
      IMPLICIT NONE
C
      REAL*8  TMJD,XJ2000(3),XEFS(3),A(3,3),XMED(3),GMT,CGMT,SGMT
     #     ,STD20R,OMT20R,OMQ20R,TWOPI
C
      DATA STD20R/1.744767163330613/, OMT20R/6.300388098984889/
     #     , OMQ20R/5.075209994113592e-15/, TWOPI/6.283185307179586/
C     
C  CONVERT XJ2000 TO THE MEAN OF DATE SYSTEM: XMED
C
      CALL PR2000(TMJD,A)
C
      XMED(1)=A(1,1)*XJ2000(1)+A(1,2)*XJ2000(2)+A(1,3)*XJ2000(3)
      XMED(2)=A(2,1)*XJ2000(1)+A(2,2)*XJ2000(2)+A(2,3)*XJ2000(3)
      XMED(3)=A(3,1)*XJ2000(1)+A(3,2)*XJ2000(2)+A(3,3)*XJ2000(3)
C
C  CONVERT XMED TO THE PSEUDO EARTH FIXED SYSTEM
C
      GMT = DMOD(STD20R+(OMT20R+OMQ20R*TMJD)*TMJD,TWOPI)
C
      CGMT = DCOS(GMT)       
      SGMT = DSIN(GMT)
C
      XEFS(1) =  CGMT * XMED(1) + SGMT * XMED(2)
      XEFS(2) = -SGMT * XMED(1) + CGMT * XMED(2)
      XEFS(3) =  XMED(3)
C      
      RETURN
      END 
C-----------------------------------------------------------------------
C
      SUBROUTINE PR2000(DAY,P)
C
CP  COMPUTES THE PRECESSION MATRIX P(3,3) FOR CONVERTING A VECTOR
C IN MEAN GEOCENTRIC EQUATORIAL SYSTEM OF 2000.0 TO MEAN-OF-DATE.
C REF: THE ASTRONOMICAL ALMANAC 1985 PAGE B18.
C
CINPUT:  DAY = MJD2000 = MOD. JULIAN DAY FOR THE MEAN-OF-DATE SYSTEM
C            = MJD(1950) - 18262.0
C
COUTPUT: P(3,3) = PRECESSION MATRIX FOR THE TRANSFORMATION:
C     R(MEAN-OF-DATE) = P(,)*R(2000)
C
      IMPLICIT REAL*8 (A-H,O-Z)
      DIMENSION P(3,3)
C
C CONVERT TO STANDARD EPOCH J2000.0 = 2000 JAN 1 AT 12:00:00
      T = DAY - 0.5D0
C
C  GZ=GREEK Z(A), ZA=Z(A), TH=THETA, ACCORDING TO THE REFERENCE.
C ORIGINAL, WITH TJC = (DAY-0.5D0)/36525.D0  IN JULIAN CENTURIES:
C     GZ = RAD*TJC*(0.6406161D0 + TJC*(839.D-7 + TJC*5.D-6))
C     ZA = GZ + RAD*TJC*TJC*(2202.D-7 + TJC*1.D-7)
C     TH = RAD*TJC*(0.5567530D0 - TJC*(1185.D-7 + TJC*116.D-7))
C
      GZ = T*(0.3061153D-6 + T*(0.10976D-14 + T*0.179D-20))
      ZA = GZ + T*T*(0.2881D-14 + T*0.358D-22)
      TH = T*(0.2660417D-6 - T*(0.1550D-14 + T*0.41549D-20))
C
      CGZ=DCOS(GZ)
      SGZ=DSIN(GZ)
      CZA=DCOS(ZA)
      SZA=DSIN(ZA)
      CTH=DCOS(TH)
      STH=DSIN(TH)
      P(1,1) = CGZ*CZA*CTH - SGZ*SZA
      P(1,2) = -SGZ*CZA*CTH - CGZ*SZA
      P(1,3) = -CZA*STH
      P(2,1) = CGZ*SZA*CTH + SGZ*CZA
      P(2,2) = -SGZ*SZA*CTH + CGZ*CZA
      P(2,3) = -SZA*STH
      P(3,1) = CGZ*STH
      P(3,2) = -SGZ*STH
      P(3,3) = CTH
      RETURN
      END
C-----------------------------------------------------------------------
